import { get } from 'lodash';
import { createServiceRequestAction } from '@springtree/eva-sdk-redux-store-builder';
import { createObservableForPath } from './pathObservable';
/**
 * Helper method to create an EVA Service context based on the Redux store
 *
 * @export
 * @template SVC
 * @param {keyof IEvaAdminStore} path
 * @param {IEvaSession} session
 * @returns {IEvaServiceContext<SVC>}
 */
export function createServiceContext(params) {
    const context = {
        getState: () => get(params.session.store.getState(), params.path),
        getState$: () => createObservableForPath(params.session.store$, `${params.path})`),
        getRequest$: () => createObservableForPath(params.session.store$, `${params.path}.data.request`),
        getResponse$: () => createObservableForPath(params.session.store$, `${params.path}.data.response`),
        isFetching$: () => createObservableForPath(params.session.store$, `${params.path}.data.fetching`),
        getError$: () => createObservableForPath(params.session.store$, `${params.path}.data.error`),
        fetch: (payload = params.defaultPayload) => {
            // Create and dispatch the REQUEST action for the service on the current
            // store for the EVA session
            //
            const action = createServiceRequestAction({
                payload,
                service: params.service,
                stateOptions: { stateKey: params.path },
            });
            params.session.store.dispatch(action);
            return action;
        },
    };
    return context;
}
//# sourceMappingURL=serviceContext.js.map